/*===========================================================================*/
/* Title   : main.c                                                          */
/* Version : V3.70                                                           */
/*===========================================================================*/
/* Copyright(c) 2010-2018 Desktop Laboratories Inc                           */
/*===========================================================================*/
/* Environment:                                                              */
/*              Device:          RL78/F14                                    */
/*              IDE:             CS+                                         */
/*===========================================================================*/

#ifdef  __CA78K0R__
  #pragma   sfr
  #pragma   DI
  #pragma   EI
  #pragma   NOP
  #include  "ICS2_typedef.h"

#elif   __CCRL__
  #define   DI()   __DI()
  #define   EI()   __EI()
  #define   NOP()  __nop()
  #include  <stdint.h>
  #include  "iodefine.h"

#elif   __ICCRL78__
  #define   DI()   __disable_interrupt()
  #define   EI()   __enable_interrupt()
  #define   NOP()  __no_operation()
  #include  <stdint.h>
  #include  <intrinsics.h>
  #include  <ior5f10ppj.h>
  #include  <ior5f10ppj_ext.h>

#endif

#include "ICS2_RL78F14.h"


/*********** KEEP DTC TABLE AREA ***********/
#ifdef  __CA78K0R__
  #pragma section @@DATA  @@DTCTBL at 0xFFD00
  char  dtc_tbl[256];
  #pragma section @@DATA  @@DATA

#elif   __CCRL__
  #pragma address dtc_tbl=0xFFD00
  char  dtc_tbl[256];

#elif   __ICCRL78__
  #pragma location=0xFFD00
  __no_init volatile char  dtc_tbl[256];

#endif


/*********** OPTION BYTE for EWRL78 Ver1.40 ***********/
#ifdef  __ICCRL78__
/* watchdog disabled, LVD off, 32MHz clock, OCD interface enabled             */
__root __far const uint8_t OptionByte[4] @ 0x00C0u = {0x0Eu,0x73u,0xE8u,0x85u};
#endif


int ia = 0;
int ib = 0;
int ic = 0;
int id = 0;
signed char ca = 0;
signed char cb = 0;
signed char cc = 0;
signed char cd = 0;

void  main(void)
{
    int i;

    DI();

  #if 1  // Internal clock
    /*-- Internal oscillator 32MHz --------------------------------*/
    CMC   = 0x00;   /* default 0x00                                */
    CKC   = 0x00;   /* default 0x00  Hispeed internal clock        */
    OSTS  = 0x07;   /* default 0x07                                */
    CSC   = 0xC0;   /* default 0xC0 X1 stop, XT1 stop, intOSC work */

    OSMC = 0x10;
    for(i=1; i<=100; i++)     /* Need 10us : 1/fx=125ns(8MHz)x100=12.5us */
    {  NOP(); }

    while(MCS == 1) { }       /* wait for clock changed */
  #endif
    
  #if 0  // External clock (20MHz)
    CMC   = 0x41;   // External clock more than 10MHz
    CSC   = 0x40;   // X1 run

    for(i=1; i<=10000; i++)     /* Need 10us : 1/fx=125ns(8MHz)x100=12.5us */
    {  NOP(); }
    
    CKC   = 0x30;   // select fmx
  #endif
    
//  BPS = CLK/(2*(Speed+1))
//  Speed         2      3      4      7     9     15
//  CLK=32MHz   5.33M  4.00M  3.20M  2.00M 1.60M  1.00M
//  CLK=20MHz   3.33M  2.50M  2.00M  1.25M 1.00M

//            DTCTBL,  PIN,                     INT DTC Speed,mode    CLK32MHz 
//  ics2_init(0xFD00, ICS_R5F10PAx_SCI0_P15_P16, 2, 0x40,  2, 4);  // OK 5.33M
//  ics2_init(0xFD00, ICS_R5F10PAx_SCI1_P12_P11, 2, 0x40,  2, 4);  // OK 5.33M

//  ics2_init(0xFD00, ICS_R5F10PBx_SCI0_P15_P16, 2, 0x40,  2, 4);  // OK 5.33M 
//  ics2_init(0xFD00, ICS_R5F10PBx_SCI0_P62_P61, 2, 0x40,  2, 4);  // OK 5.33M 
//  ics2_init(0xFD00, ICS_R5F10PBx_SCI1_P12_P11, 2, 0x40,  2, 4);  // OK 5.33M 

//  ics2_init(0xFD00, ICS_R5F10PGx_SCI0_P15_P16, 2, 0x40,  2, 4);  // OK 5.33M
//  ics2_init(0xFD00, ICS_R5F10PGx_SCI0_P62_P61, 2, 0x40,  2, 4);  // OK 5.33M
//  ics2_init(0xFD00, ICS_R5F10PGx_SCI1_P12_P11, 2, 0x40,  2, 4);  // OK 5.33M

//  ics2_init(0xFD00, ICS_R5F10PLx_SCI0_P15_P16, 2, 0x40,  2, 4);  // OK 5.33M
//  ics2_init(0xFD00, ICS_R5F10PLx_SCI0_P62_P61, 2, 0x40,  2, 4);  // OK 5.33M
    ics2_init(0xFD00, ICS_R5F10PLx_SCI1_P12_P11, 2, 0x40,  2, 4);  // OK 5.33M (ECU001 CN9) default
//  ics2_init(0xFD00, ICS_R5F10PLx_SCI1_P74_P75, 2, 0x40,  2, 4);  // OK 5.33M

//  ics2_init(0xFD00, ICS_R5F10PMx_SCI0_P15_P16, 2, 0x40,  2, 4);  // OK 5.33M  
//  ics2_init(0xFD00, ICS_R5F10PMx_SCI0_P62_P61, 2, 0x40,  2, 4);  // OK 5.33M (T5102 CN4)   
//  ics2_init(0xFD00, ICS_R5F10PMx_SCI1_P12_P11, 2, 0x40,  2, 4);  // OK 5.33M   
//  ics2_init(0xFD00, ICS_R5F10PMx_SCI1_P74_P75, 2, 0x40,  2, 4);  // OK 5.33M (T5102 CN5)   

//  ics2_init(0xFD00, ICS_R5F10PPx_SCI0_P15_P16, 2, 0x40,  2, 4);  // OK 5.33M   
//  ics2_init(0xFD00, ICS_R5F10PPx_SCI0_P62_P61, 2, 0x40,  2, 4);  // OK 5.33M   
//  ics2_init(0xFD00, ICS_R5F10PPx_SCI1_P12_P11, 2, 0x40,  2, 4);  // OK 5.33M  
//  ics2_init(0xFD00, ICS_R5F10PPx_SCI1_P74_P75, 2, 0x40,  2, 4);  // OK 5.33M    

//  ics2_init(0xFD00, ICS_R5F10PLx_SCI1_P12_P11, 2, 0x40,  2, 0);  // OK 5.33M  8/16bit  8ch mode
//  ics2_init(0xFD00, ICS_R5F10PLx_SCI1_P12_P11, 2, 0x40,  2, 6);  // OK 5.33M  16bit    8ch mode
//  ics2_init(0xFD00, ICS_R5F10PLx_SCI1_P12_P11, 2, 0x40,  2, 4);  // OK 5.33M  8/16bit 15ch mode


    EI();

    while (1)
    {
        int i;

        ia = ia + 1;
        if (ia>100) { ia = -100; }
        ib = -ia;
        ic = ia>>1;
        ca = (signed char)ia;
        cb = (signed char)ib;
        cc = (signed char)ic;

        ics2_watchpoint();
        for(i=0;i<2000;i++) { NOP();  NOP(); }
    }
}


